/*
 *    GSFile.java
 *    Copyright (C) 2002 New Zealand Digital Library, http://www.nzdl.org
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.greenstone.gsdl3.util;

import java.io.File; 

/**
 * GSFiles - utility class for Greenstone.
 *
 * contains File creation methods.
 *
 * @author <a href="mailto:kjdon@cs.waikato.ac.nz">Katherine Don</a>
 * @version $Revision: 3235 $
 * @see File
 */
public class GSFile {

    /** creates a File for the site config file */
    static public File siteConfigFile(String site_home) {
	return new File(site_home + File.separatorChar+"sitecfg.xml");

    }

    /** creates a File for the collection directory  */
    static public File collectionDirFile(String site_home) {
	return new File(site_home+File.separatorChar+"collect");
    }
    
    /** creates a File for the collection config file */
    static public File collectionConfigFile(String site_home, 
					    String collection_name) {
	return new File(site_home+File.separatorChar+"collect"+
			File.separatorChar+collection_name+
			File.separatorChar+"etc"+
			File.separatorChar+"collectcfg.xml");

    }

    /** creates a File for the collection build config file */
    static public File collectionBuildConfigFile(String site_home, 
						 String collection_name ) {
	return new File(site_home+File.separatorChar+"collect"+
			File.separatorChar+collection_name+
			File.separatorChar+"index"+
			File.separatorChar+"buildcfg.xml");
    }

    /** returns the directory for XML Transforms */
    static public String xmlTransformDir(String gsdl_home) {
	return gsdl_home+File.separatorChar+"transform";
    }
	    

}
